A drop-in compatible rust implementation of bzip2
Structs
Constants
- BZ_
CONFIG_ ERROR - BZ_
DATA_ ERROR - BZ_
DATA_ ERROR_ MAGIC - BZ_
FINISH - BZ_
FINISH_ OK - BZ_
FLUSH - BZ_
FLUSH_ OK - BZ_
IO_ ERROR - BZ_
MAX_ UNUSED - BZ_
MEM_ ERROR - BZ_OK
- BZ_
OUTBUFF_ FULL - BZ_
PARAM_ ERROR - BZ_RUN
- BZ_
RUN_ OK - BZ_
SEQUENCE_ ERROR - BZ_
STREAM_ END - BZ_
UNEXPECTED_ EOF
Functions
- BZ2_
bzBuff ⚠ToBuff Compress - Compress the input data into the destination buffer.
- BZ2_
bzBuff ⚠ToBuff Decompress - Decompress the input data into the destination buffer.
- BZ2_
bzCompress ⚠ - Compresses as much data as possible, and stops when the input buffer becomes empty or the output buffer becomes full.
- BZ2_
bzCompress ⚠End - Deallocates all dynamically allocated data structures for this stream.
- BZ2_
bzCompress ⚠Init - Prepares the stream for compression.
- BZ2_
bzDecompress ⚠ - Decompresses as much data as possible, and stops when the input buffer becomes empty or the output buffer becomes full.
- BZ2_
bzDecompress ⚠End - Deallocates all dynamically allocated data structures for this stream.
- BZ2_
bzDecompress ⚠Init - Prepares the stream for decompression.
- BZ2_
bzRead ⚠ - Reads up to
len(uncompressed) bytes from the compressed filebinto the bufferbuf. - BZ2_
bzRead ⚠Close - Releases all memory associated with a
BZFILEopened withBZ2_bzReadOpen. - BZ2_
bzRead ⚠GetUnused - Returns data which was read from the compressed file but was not needed to get to the logical end-of-stream.
- BZ2_
bzRead ⚠Open - Prepare to read compressed data from a file handle.
- BZ2_
bzWrite ⚠ - Absorbs
lenbytes from the bufferbuf, eventually to be compressed and written to the file. - BZ2_
bzWrite ⚠Close - Compresses and flushes to the compressed file all data so far supplied by
BZ2_bzWrite. - BZ2_
bzWrite ⚠Close64 - Compresses and flushes to the compressed file all data so far supplied by
BZ2_bzWrite. - BZ2_
bzWrite ⚠Open - Prepare to write compressed data to a file handle.
- BZ2_
bzclose ⚠ - Closes a
BZFILE. - BZ2_
bzdopen ⚠ - Opens a
.bz2file for reading or writing using a pre-existing file descriptor. Analogous tolibc::fdopen. - BZ2_
bzerror ⚠ - Describes the most recent error.
- BZ2_
bzflush ⚠ - Flushes a
BZFILE. - BZ2_
bzlib Version - The version of the zlib library.
- BZ2_
bzopen ⚠ - Opens a
.bz2file for reading or writing using its name. Analogous tolibc::fopen. - BZ2_
bzread ⚠ - Reads up to
len(uncompressed) bytes from the compressed filebinto the bufferbuf. - BZ2_
bzwrite ⚠ - Absorbs
lenbytes from the bufferbuf, eventually to be compressed and written to the file.